/****************************************************************************
 * @file DS1302.h - MAXIM DS1302 Real Time Clock API header file
 * Copyright (c) 2009, Craig Smith
 * See end of file for MIT license terms.
 ****************************************************************************/

#include <propeller.h>
#ifndef __DS1302_h__
#define __DS1302_h__

#ifndef BYTE
  #define BYTE unsigned char
#endif

// structure used for ds1302_setDatetime and ds1302_getDatetime
struct ds1302_dateTime {   
      BYTE month;          
      BYTE day;
      BYTE year;
      BYTE dow;            // dow is day of week
      BYTE hour;
      BYTE minute;
      BYTE second;
      BYTE pm;             // TRUE if PM
      BYTE is12HrMode;     // TRUE for 12 hour mode instead of 24 hour mode
};

void ds1302_init(BYTE clkPin, BYTE ioPin, BYTE cePin);
void ds1302_setDatetime(struct ds1302_dateTime dt);
void ds1302_getDatetime(struct ds1302_dateTime *dt);
void ds1302_setDay(BYTE day);
BYTE ds1302_getDay(void);
void ds1302_setMonth(BYTE month);
BYTE ds1302_getMonth(void);
void ds1302_setYear(BYTE year);
BYTE ds1302_getYear(void);
void ds1302_setDOW(BYTE dow);
BYTE ds1302_getDOW(void);
void ds1302_setHour(BYTE hour);
BYTE ds1302_getHour(void);
void ds1302_setMinute(BYTE minute);
BYTE ds1302_getMinute(void);
void ds1302_setSecond(BYTE second);
BYTE ds1302_getSecond(void);
void ds1302_setPM(BYTE pm);
BYTE ds1302_getPM(void);
void ds1302_set12HourMode(BYTE goto12HourMode);
BYTE ds1302_get12HourMode(void);
void ds1302_setWriteProtect(BYTE on);
BYTE ds1302_getWriteProtect(void);
void ds1302_setClockHalt(BYTE halt);
BYTE ds1302_getClockHalt(void);
void ds1302_setTrickleCharge(BYTE mode);
BYTE ds1302_getTrickleCharge(void);
void ds1302_setRamByte(BYTE address, BYTE data);
BYTE ds1302_getRamByte(BYTE address);
void ds1302_setRamBlock(BYTE address, BYTE length, BYTE *data);
void ds1302_getRamBlock(BYTE address, BYTE length, BYTE *data);

// macros for bit fiddling in C

#define CHECKBIT(ADDRESS,BIT) (ADDRESS & (1<<BIT))
#define SETBITMASK(x,y) (x |= (y))
#define CLEARBITMASK(x,y) (x &= (~y))
// See propeller.h for definitions of SET and CLR

#define _1224BIT 7		   // 12/24 hour mode bit in DS1302
#define AMPMBIT 5          // AM/PM bit in DS1302

#endif
// __DS1302_h__

/*
+-----------------------------------------------------------------------------+
                         TERMS OF USE: MIT License                           
+-----------------------------------------------------------------------------
Permission is hereby granted, free of charge, to any person obtaining a copy 
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights 
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell    
copies of the Software, and to permit persons to whom the Software is        
furnished to do so, subject to the following conditions:                     
                                                                             
 The above copyright notice and this permission notice shall be included in  
 all copies or substantial portions of the Software.                         
                                                                             
 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR  
 IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,    
 FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE 
 AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER      
 LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING     
 FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER         
 DEALINGS IN THE SOFTWARE.                                                   
+-----------------------------------------------------------------------------+
*/