/******************************************************************
 * @file DS1302Test.c - MAXIM DS1302 Real Time Clock library test.
 * Copyright (c) 2009, Craig Smith
 * See end of file for MIT license terms.
 ******************************************************************/
 
#include <stdio.h>
#include <propeller.h>
#include "tv_text.h"
#include "DS1302.h"

#define CLK_PIN 29                       // DS1302 CLK pin
#define IO_PIN 28                        // DS1302 IO pin
#define CE_PIN 27                        // DS1302 CE pin
#define TV_PIN 12                        // TV pin


void main(void)
{
	struct ds1302_dateTime dt;             // dt will hold date and time info
	char test[10];
	
    tvText_start(TV_PIN);                  // start TV

	ds1302_init(CLK_PIN, IO_PIN, CE_PIN);  // set clock to default options

    dt.month = 3;                          // store the new time and 
    dt.day = 27;                           //  date in dt
    dt.year = 9;
    dt.dow = 6;
    dt.hour = 1;
    dt.minute = 59;
    dt.second = 50;
    dt.is12HrMode = TRUE;                 // clock will default to 24 hr mode
    dt.pm = TRUE;                         // this doesn't matter in 12 hr mode
	ds1302_setDatetime(dt);                // now set the time/date in DS1302
	ds1302_setRamBlock(0, 7, "ICCV7!");    // write a string to DS1302 RAM
	ds1302_setRamByte(10, 222);                // store a byte in DS1302 RAM	
	 
    tvText_setXY(0,0);
	printf("[DS1302 Test]");

    while(1) 
	{
		ds1302_getDatetime(&dt);           // read the time into structure dt
		
		tvText_setXY(16,0);                // display time
        tvText_str("Time: ");
		if (dt.hour<10) tvText_out('0');   // pad with 0 if < 10
        tvText_dec(dt.hour);
		tvText_out(':');
		if (dt.minute<10) tvText_out('0');
        tvText_dec(dt.minute);
		tvText_out(':');
		if (dt.second<10) tvText_out('0');
        tvText_dec(dt.second);
		if (dt.is12HrMode)
		  {
		  if (dt.pm)
            tvText_str(" PM");
		  else
            tvText_str(" AM");
		  }
		else
          tvText_str("   ");
		
		tvText_setXY(16,2);                // display date
        tvText_str("Date: ");
		if (dt.month<10) tvText_out('0');
        tvText_dec(dt.month);
		tvText_out('/');
		if (dt.day<10) tvText_out('0');
        tvText_dec(dt.day);
		tvText_out('/');
		if (dt.year<10) tvText_out('0');
        tvText_dec(dt.year);

		tvText_setXY(16,4);                // display day of week
        tvText_str(" DOW: ");
        tvText_dec(dt.dow);
		
        tvText_setXY(16,5);                // display AM/PM status
        tvText_str("  PM: ");
		if (dt.pm)
          tvText_str("TRUE ");
		else
          tvText_str("FALSE");
		
        tvText_setXY(16,6);                // display 12/24 hour mode
        tvText_str("12Hr: ");
        if (dt.is12HrMode)
          tvText_str("TRUE ");
		else
          tvText_str("FALSE");

        tvText_setXY(13,8);                // display 12/24 hour mode
        tvText_str("Trickle: ");
        tvText_dec(ds1302_getTrickleCharge());

		  
        tvText_setXY(12,10);                // read and display a block of RAM
        tvText_str("RAM[0-8]: ");
		ds1302_getRamBlock(0, 7, test);
        tvText_str(test);
		
        tvText_setXY(13,11);                // read and display one byte of RAM
        tvText_str("RAM[10]: ");
		tvText_dec(ds1302_getRamByte(10));		
	}
}

/*
+------------------------------------------------------------------------------------------------------------------------------+
                                                   TERMS OF USE: MIT License                                                                                                              
+------------------------------------------------------------------------------------------------------------------------------
Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation     
files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy,    
modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software
is furnished to do so, subject to the following conditions:                                                                   
                                                                                                                              
The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.
                                                                                                                              
THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE          
WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR         
COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,   
ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.                         
+------------------------------------------------------------------------------------------------------------------------------+
*/